package javadoc;

import java.io.*;
import java.net.URI;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.StringTokenizer;

import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.INKFResponse;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

public class ListBootJars extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		String installPathDir=aContext.getKernelContext().getKernel().getConfiguration().getString("netkernel.install.path");
		URI u=new URI(installPathDir+"etc/bootloader.conf");
		File bootloaderFile = new File(u);
		BufferedReader r = new BufferedReader(new InputStreamReader(new FileInputStream(bootloaderFile)));
		HDSBuilder b = new HDSBuilder();
		b.pushNode("modules");
		String line;
		int index=0;
		while ((line=r.readLine())!=null)
		{	line=line.trim();
			if (!line.startsWith("#") && line.length()>0)
			{	String src=installPathDir+line;
				StringTokenizer st = new StringTokenizer(line,"/");
				String id=null;
				while(st.hasMoreTokens())
				{	id=st.nextToken();
				}
				b.pushNode("module");
				b.addNode("source", src);
				b.addNode("runlevel", "0");
				b.addNode("version", "");
				b.addNode("id", id.toLowerCase());
				String dotted=dotted(id.toLowerCase());
				b.addNode("dotted", dotted);
				b.addNode("guid", index++);
				String dest=dest(installPathDir,dotted,"");
				b.addNode("dest", dest);
				b.addNode("touch", destTime(dest));
				
				b.popNode();
			}
		}
		
		IHDSNode modules=aContext.source("active:moduleListDoc",IHDSNode.class);
		for (IHDSNode module : modules.getNodes("/modules/module"))
		{
			b.pushNode("module");
			for (String s: new String[] { "runlevel","source","version","id" })
			{	Object value=module.getFirstValue(s);
				b.addNode(s, value);
			}
			String dotted=dotted(module.getFirstValue("id").toString().toLowerCase());
			String version=module.getFirstValue("version").toString();
			b.addNode("dotted", dotted);
			b.addNode("guid", index++);
			String dest=dest(installPathDir,dotted,version);
			b.addNode("dest", dest);
			b.addNode("touch", destTime(dest));
			b.popNode();
		}
		
		aContext.createResponseFrom(b.getRoot()).setExpiry(INKFResponse.EXPIRY_CONSTANT,System.currentTimeMillis()+2000L);
	}
	
	public String dotted(String aIn)
	{	return aIn.replaceAll("\\:", ".");
	}
	
	public String dest(String aInstallbase, String aDotted, String aVersion)
	{	return aInstallbase+"javadoc/"+aDotted+"-"+aVersion+"/";
	}
	
	public String destTime(String aDest) throws Exception
	{	String result="";
		try
		{	File destf=new File(URI.create(aDest));
			if (destf.exists())
			{	long lm=destf.lastModified();
				DateFormat df=DateFormat.getDateInstance(DateFormat.SHORT); //new SimpleDateFormat();
				result = df.format(new Date(lm));
			}
		}
		catch (Exception e)
		{
		}
		return result;
	}
	
}
