package org.netkernel.doc.endpoint;

import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

import java.io.LineNumberReader;
import java.io.StringReader;


/**
 * This engine will return the enclosed text with a background color that indicates this
 * document is not a final, edited and approved version.
 */


public class NotFinalEngine extends StandardAccessorImpl
  {
  public NotFinalEngine()
    {
    this.declareThreadSafe();
    }


  @Override
  public void onSource(INKFRequestContext context) throws Exception
    {
    INKFRequest request;

    String type = context.getThisRequest().getArgumentValue("activeType");
    String content = context.source("arg:operand", String.class);

    if (type.endsWith("XHTML"))
      {
      // XHTML
      // Perform Wiki Markup processing on the macro contents
//      String tempCWU=context.getCWU();
//      context.setCWU(null);
      request = context.createRequest("active:wikiParser/XHTML");
      request.addArgumentByValue("operand", content);
      request.addArgument("base", ".");
      request.setRepresentationClass(String.class);
      content = (String) context.issueRequest(request);
      if (type.contains("REVIEW"))
        {
        context.createResponseFrom("<div class=\"review\">" + content + "</div>");
        }
      else if (type.contains("EDITOR"))
        {
        context.createResponseFrom("<div class=\"editor\">" + content + "</div>");
        }
      else if (type.contains("DRAFT"))
        {
        context.createResponseFrom("<div class=\"draft\">" + content + "</div>");
        }
      else if (type.contains("CANDIDATE"))
        {
        context.createResponseFrom("<div class=\"candidate\">" + content + "</div>");
        }
      else
        {
        context.createResponseFrom("<div style=\"background-color: white;\">" + content + "</div>");
        }
      }
    else
      {  //Docbook
      // Perform Wiki Markup processing on the macro contents
//      String tempCWU=context.getCWU();
//      context.setCWU(null);
      request = context.createRequest("active:wikiParser/DOCBOOK");
      request.addArgumentByValue("operand", content);
      request.addArgument("base", ".");
      request.setRepresentationClass(String.class);
      content = (String) context.issueRequest(request);

      // There is no impact on DocBook presentation
      context.createResponseFrom(content);
      }
    }

  }
